Skip to contents

Start an FFmpeg pipeline by specifying input and output files.

Usage

ffm_files(input, output, overwrite = TRUE)

Arguments

input

A character vector of paths to the input media files of the pipeline. Give more than one path for stacking.

output

A string with the path of the output media file of the pipeline.

overwrite

A logical. If TRUE (the default), an output media file that already exists is overwritten.

Value

An FFmpeg pipeline object.

Examples

video <- system.file("extdata", "sample.mp4", package = "tidymedia")
ffm_files(video, "output.mp4") |>
  ffm_compile()
#> [1] "-y -i \"/home/runner/work/_temp/Library/tidymedia/extdata/sample.mp4\" \"output.mp4\""