| ffm_fps | R Documentation |
Resample the video to a constant frame rate with FFmpeg's fps filter.
The filter duplicates or drops frames as needed. It is added to the end of
the video filters, like the other filters that take one input. The glossary
in vignette("tidymedia") explains media terms such as frame rate.
ffm_fps(object, fps)
object |
An FFmpeg pipeline ( |
fps |
The target frame rate. Give a positive real number of frames per
second, or a string that contains an FFmpeg frame rate expression. For
example, |
object with an added instruction to resample the frame rate.
standardize_video(), the task function that uses ffm_fps()
to set the frame rate.
Other pipeline functions:
ffm_batch(),
ffm_codec(),
ffm_compile(),
ffm_concat(),
ffm_copy(),
ffm_crop(),
ffm_drawbox(),
ffm_drop(),
ffm_files(),
ffm_hstack(),
ffm_jobs(),
ffm_loudnorm(),
ffm_map(),
ffm_output_options(),
ffm_overlay(),
ffm_pixel_format(),
ffm_run(),
ffm_scale(),
ffm_seek(),
ffm_trim(),
ffm_vstack(),
print.tidymedia_ffm()
video <- system.file("extdata", "sample.mp4", package = "tidymedia")
ffm_files(video, "output.mp4") |>
ffm_fps(fps = 30) |>
ffm_compile()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.