Skip to contents

get_height() uses the MediaInfo program to look up the video height of a media file, in pixels (px).

Usage

get_height(file)

Arguments

file

A character vector of one or more media file paths.

Value

A double vector (one per file) giving the video height in px.

Details

The function returns one number for each file. The probe_*() functions, mediainfo_query() and mediainfo_template() return tibbles instead.

See also

Examples

video <- system.file("extdata", "sample.mp4", package = "tidymedia")
get_height(video)
#> [1] 240