| get_samplingrate | R Documentation |
Use MediaInfo to quickly look up the audio sampling rate of a media file in hertz (Hz).
get_samplingrate(file)
file |
A string containing the file path of a media file. |
A double indicating the audio sampling rate of file (in Hz).
Other mediainfo functions:
get_duration(),
get_framerate(),
get_height(),
get_width(),
mediainfo(),
mediainfo_parameter(),
mediainfo_query(),
mediainfo_template()
Other convenience functions:
get_duration(),
get_framerate(),
get_height(),
get_width()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.