| extract_frame | R Documentation |
Save one frame of a video to an image file, selected either by timestamp or
by frame number. Provide exactly one of timestamp or frame.
extract_frame(infile, outfile, timestamp = NULL, frame = NULL, run = TRUE)
infile |
A string containing the path to a video file. |
outfile |
A string containing the path of the image file to write. |
timestamp |
Either a number of seconds, a time-duration-syntax string,
or |
frame |
Either an integerish frame number or |
run |
A logical: run the command through FFmpeg ( |
The compiled FFmpeg command (invisibly when run = TRUE).
ffm_seek(), the pipeline function it uses to get the frame.
extract_frame_batch() for the many-file (batch) form.
Other task functions:
anonymize_video(),
anonymize_video_batch(),
compare_videos(),
compare_videos_batch(),
concatenate_videos(),
concatenate_videos_batch(),
convert_audio(),
convert_audio_batch(),
crop_video(),
crop_video_batch(),
extract_audio(),
extract_audio_batch(),
extract_frame_batch(),
format_for_web(),
format_for_web_batch(),
normalize_audio(),
normalize_audio_batch(),
picture_in_picture(),
picture_in_picture_batch(),
sample_frames(),
sample_frames_batch(),
segment_video(),
segment_video_batch(),
separate_audio_video(),
separate_audio_video_batch(),
standardize_video(),
standardize_video_batch(),
strip_metadata(),
strip_metadata_batch()
video <- system.file("extdata", "sample.mp4", package = "tidymedia")
# run = FALSE returns the reproducible command instead of executing it
extract_frame(video, "frame.png", timestamp = 0.5, run = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.