| ffm_compile | R Documentation |
Compile all the instructions into one string, the FFmpeg command that runs them.
ffm_compile(object)
object |
An FFmpeg pipeline ( |
A string with the FFmpeg command that carries out all the instructions in the tidymedia pipeline.
ffm_run() to compile and run in one step, and ffm_batch() to
compile over many files.
Other pipeline functions:
ffm_batch(),
ffm_codec(),
ffm_concat(),
ffm_copy(),
ffm_crop(),
ffm_drawbox(),
ffm_drop(),
ffm_files(),
ffm_fps(),
ffm_hstack(),
ffm_jobs(),
ffm_loudnorm(),
ffm_map(),
ffm_output_options(),
ffm_overlay(),
ffm_pixel_format(),
ffm_run(),
ffm_scale(),
ffm_seek(),
ffm_trim(),
ffm_vstack(),
print.tidymedia_ffm()
video <- system.file("extdata", "sample.mp4", package = "tidymedia")
# ffm_compile() returns the reproducible FFmpeg command as a string
ffm_files(video, "output.mp4") |>
ffm_trim(start = 1, end = 5) |>
ffm_crop(width = 160, height = 120) |>
ffm_codec(video = "libx264") |>
ffm_compile()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.