| ffm_scale | R Documentation |
Scale (resize) the input video's frames to a width and height in pixels, or with an FFmpeg expression.
ffm_scale(object, width, height)
object |
An FFmpeg pipeline ( |
width |
The width of the output video, in pixels. Give a positive real number or a string that contains an FFmpeg expression. |
height |
The height of the output video, in pixels. Give a positive real number or a string that contains an FFmpeg expression. |
object with an added instruction to resize the frames.
ffm_crop() to crop instead of resize. standardize_video() is the
task function built on ffm_scale().
Other pipeline functions:
ffm_batch(),
ffm_codec(),
ffm_compile(),
ffm_concat(),
ffm_copy(),
ffm_crop(),
ffm_drawbox(),
ffm_drop(),
ffm_files(),
ffm_fps(),
ffm_hstack(),
ffm_jobs(),
ffm_loudnorm(),
ffm_map(),
ffm_output_options(),
ffm_overlay(),
ffm_pixel_format(),
ffm_run(),
ffm_seek(),
ffm_trim(),
ffm_vstack(),
print.tidymedia_ffm()
video <- system.file("extdata", "sample.mp4", package = "tidymedia")
ffm_files(video, "output.mp4") |>
ffm_scale(width = 160, height = 120) |>
ffm_compile()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.