| ffmpeg | R Documentation |
Send a raw argument string to the FFmpeg command-line program. This is a direct command. The function passes the string to FFmpeg unchanged, after the path of the FFmpeg program. So you are responsible for the quoting and the order of the options.
ffmpeg(command)
command |
A string containing the arguments to pass to FFmpeg. |
A character vector containing the text output by FFmpeg.
ffmpeg_codecs() and ffmpeg_encoders() ask FFmpeg what it
supports. The ffm_*() pipeline functions, such as
ffm_run(), are a safer way to build a command.
Other direct command functions:
ffprobe(),
mediainfo()
# A direct command: the function passes the string to FFmpeg unchanged
ffmpeg("-version")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.