Ask FFmpeg for its list of installed codecs, and return the list as a data
frame with information about each codec. The glossary in
vignette("tidymedia") explains media terms such as codec and encoder.
Value
A tibble with the following variables:
- name
A character vector including the name/code of each codec
- details
A character vector including details about each codec
- type
A factor vector indicating whether each codec supports
"Video","Audio"or"Subtitles"- decoding
A logical vector indicating whether each codec supports decoding
- encoding
A logical vector indicating whether each codec supports encoding
- intraframe
A logical vector indicating whether each codec is an intra-frame-only codec
- lossy
A logical vector indicating whether each codec supports lossy compression
- lossless
A logical vector indicating whether each codec supports lossless compression
See also
ffmpeg_encoders() for the encoder list, ffm_codec() to set a
codec in a pipeline, and ffmpeg() for the direct command.
Other capability functions:
ffmpeg_encoders(),
hardware_encoder(),
refresh_ffmpeg_capabilities()
Examples
head(ffmpeg_codecs())
#> # A tibble: 6 × 8
#> name details type decoding encoding intraframe lossy lossless
#> <chr> <chr> <fct> <lgl> <lgl> <lgl> <lgl> <lgl>
#> 1 012v Uncompressed 4:2… Video TRUE FALSE TRUE FALSE TRUE
#> 2 4xm 4X Movie Video TRUE FALSE FALSE TRUE FALSE
#> 3 8bps QuickTime 8BPS v… Video TRUE FALSE TRUE FALSE TRUE
#> 4 a64_multi Multicolor chars… Video FALSE TRUE TRUE TRUE FALSE
#> 5 a64_multi5 Multicolor chars… Video FALSE TRUE TRUE TRUE FALSE
#> 6 aasc Autodesk RLE Video TRUE FALSE FALSE FALSE TRUE
ffmpeg_codecs(sort_by_type = FALSE)
#> # A tibble: 517 × 8
#> name details type decoding encoding intraframe lossy lossless
#> <chr> <chr> <fct> <lgl> <lgl> <lgl> <lgl> <lgl>
#> 1 012v Uncompressed 4:… Video TRUE FALSE TRUE FALSE TRUE
#> 2 4gv 4GV (Fourth Gen… Audio FALSE FALSE TRUE TRUE FALSE
#> 3 4xm 4X Movie Video TRUE FALSE FALSE TRUE FALSE
#> 4 8bps QuickTime 8BPS … Video TRUE FALSE TRUE FALSE TRUE
#> 5 8svx_exp 8SVX exponential Audio TRUE FALSE TRUE TRUE FALSE
#> 6 8svx_fib 8SVX fibonacci Audio TRUE FALSE TRUE TRUE FALSE
#> 7 a64_multi Multicolor char… Video FALSE TRUE TRUE TRUE FALSE
#> 8 a64_multi5 Multicolor char… Video FALSE TRUE TRUE TRUE FALSE
#> 9 aac AAC (Advanced A… Audio TRUE TRUE TRUE TRUE FALSE
#> 10 aac_latm AAC LATM (Advan… Audio TRUE FALSE TRUE TRUE FALSE
#> # ℹ 507 more rows