| ffmpeg_codecs | R Documentation |
Ask FFmpeg for its list of installed codecs, and return the list as a data
frame with information about each codec. The glossary in
vignette("tidymedia") explains media terms such as codec and encoder.
ffmpeg_codecs(sort_by_type = TRUE)
sort_by_type |
A logical. |
A tibble with the following variables:
name |
A character vector including the name/code of each codec |
details |
A character vector including details about each codec |
type |
A factor vector indicating whether each codec supports
|
decoding |
A logical vector indicating whether each codec supports decoding |
encoding |
A logical vector indicating whether each codec supports encoding |
intraframe |
A logical vector indicating whether each codec is an intra-frame-only codec |
lossy |
A logical vector indicating whether each codec supports lossy compression |
lossless |
A logical vector indicating whether each codec supports lossless compression |
ffmpeg_encoders() for the encoder list, ffm_codec() to set a
codec in a pipeline, and ffmpeg() for the direct command.
Other capability functions:
ffmpeg_encoders(),
hardware_encoder(),
has_encoder(),
refresh_ffmpeg_capabilities()
head(ffmpeg_codecs())
ffmpeg_codecs(sort_by_type = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.