| get_duration | R Documentation |
Use MediaInfo to quickly look up the duration of different sections of a media file in various units.
get_duration(
file,
section = c("General", "Video", "Audio"),
unit = c("ms", "sec", "min", "hour")
)
file |
A string containing the file path of a media file. |
section |
A string indicating the MediaInfo section from which to query
the duration value. Can be either |
unit |
A string indicating whether the duration should be returned in
milliseconds ( |
A double indicating the duration of the specified section of the file (in the specified units).
Other mediainfo functions:
get_framerate(),
get_height(),
get_samplingrate(),
get_width(),
mediainfo(),
mediainfo_parameter(),
mediainfo_query(),
mediainfo_template()
Other convenience functions:
get_framerate(),
get_height(),
get_samplingrate(),
get_width()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.