| get_height | R Documentation |
Use MediaInfo to quickly look up the video height of a media file in pixels (px).
get_height(file)
file |
A string containing the file path of a media file. |
A double indicating the video height of file (in px).
Other mediainfo functions:
get_duration(),
get_framerate(),
get_samplingrate(),
get_width(),
mediainfo(),
mediainfo_parameter(),
mediainfo_query(),
mediainfo_template()
Other convenience functions:
get_duration(),
get_framerate(),
get_samplingrate(),
get_width()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.