| get_width | R Documentation |
Use MediaInfo to quickly look up the video width of a media file in pixels (px).
get_width(file)
file |
A string containing the file path of a media file. |
A double indicating the video width of file (in px).
Other mediainfo functions:
get_duration(),
get_framerate(),
get_height(),
get_samplingrate(),
mediainfo(),
mediainfo_parameter(),
mediainfo_query(),
mediainfo_template()
Other convenience functions:
get_duration(),
get_framerate(),
get_height(),
get_samplingrate()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.