| mediainfo_parameter | R Documentation |
Query a single parameter in a single section from MediaInfo and return it as an atomic object (not a tibble).
mediainfo_parameter(file, section, parameter)
file |
A string containing the path to a media file. |
section |
A string containing the name of the mediainfo
section from which to query |
parameter |
A string containing the name of the mediainfo
parameter to query from |
A string or double containing the requested parameter's value or
NA in the cases that the value was empty or the section-parameter
combination could not be found.
Other mediainfo functions:
get_duration(),
get_framerate(),
get_height(),
get_samplingrate(),
get_width(),
mediainfo(),
mediainfo_query(),
mediainfo_template()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.