| mediainfo_query | R Documentation |
Create a new row tibble that contains multiple parameters from a single
MediaInfo section. To query parameters from multiple sections at the same
time, use either mediainfo_summary() or mediainfo_template().
mediainfo_query(file, section, parameters, names = parameters)
file |
A string indicating the path to a media file. |
section |
A string indicating the MediaInfo section from which to query
the |
parameters |
A vector of one or more strings indicating the MediaInfo
parameters to query from |
names |
A vector of one or more strings indicating the names of the
variables in the returned tibble; must be the same length as
|
A row tibble containing each parameter as a separate variable.
Other mediainfo functions:
get_duration(),
get_framerate(),
get_height(),
get_samplingrate(),
get_width(),
mediainfo(),
mediainfo_parameter(),
mediainfo_template()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.